@@ -1236,24 +1236,7 @@ HICON16 WINAPI CreateIcon16( HINSTANCE16 hInstance, INT16 nWidth,
  *  Success: handle to an icon
  *  Failure: NULL
  *
- * BUGS
- *
- *  - The provided bitmaps are not resized!
- *  - The documentation says the lpXORbits bitmap must be in a device
- *    dependent format. But we must still resize it and perform depth
- *    conversions if necessary.
- *  - I'm a bit unsure about the how the 'device dependent format' thing works.
- *    I did some tests on windows and found that if you provide a 16bpp bitmap
- *    in lpXORbits, then its format but be 565 RGB if the screen's bit depth
- *    is 16bpp but it must be 555 RGB if the screen's bit depth is anything
- *    else. I don't know if this is part of the GDI specs or if this is a
- *    quirk of the graphics card driver.
- *  - You may think that we check whether the bit depths match or not
- *    as an optimization. But the truth is that the conversion using
- *    CreateDIBitmap does not work for some bit depth (e.g. 8bpp) and I have
- *    no idea why.
- *  - I'm pretty sure that all the things we do in CreateIcon should
- *    also be done in CreateIconIndirect...
+ * FIXME: Do we need to resize the bitmaps?
  */
 HICON WINAPI CreateIcon(
     HINSTANCE hInstance,  /* [in] the application's hInstance */
@@ -1264,58 +1247,23 @@ HICON WINAPI CreateIcon(
     LPCVOID   lpANDbits,  /* [in] a monochrome bitmap representing the icon's mask */
     LPCVOID   lpXORbits)  /* [in] the icon's 'color' bitmap */
 {
+    ICONINFO iinfo;
     HICON hIcon;
-    HDC hdc;
 
-    TRACE_(icon)("%dx%dx%d, xor=%p, and=%p\n",
-                 nWidth, nHeight, bPlanes * bBitsPixel, lpXORbits, lpANDbits);
+    TRACE_(icon)("%dx%d, planes %d, bpp %d, xor %p, and %p\n",
+                 nWidth, nHeight, bPlanes, bBitsPixel, lpXORbits, lpANDbits);
 
-    hdc=GetDC(0);
-    if (!hdc)
-        return 0;
+    iinfo.fIcon = TRUE;
+    iinfo.xHotspot = ICON_HOTSPOT;
+    iinfo.yHotspot = ICON_HOTSPOT;
+    iinfo.hbmMask = CreateBitmap( nWidth, nHeight, 1, 1, lpANDbits );
+    iinfo.hbmColor = CreateBitmap( nWidth, nHeight, bPlanes, bBitsPixel, lpXORbits );
 
-    if (GetDeviceCaps(hdc,BITSPIXEL)==bBitsPixel) {
-        CURSORICONINFO info;
+    hIcon = CreateIconIndirect( &iinfo );
 
-        info.ptHotSpot.x = ICON_HOTSPOT;
-        info.ptHotSpot.y = ICON_HOTSPOT;
-        info.nWidth = nWidth;
-        info.nHeight = nHeight;
-        info.nWidthBytes = 0;
-        info.bPlanes = bPlanes;
-        info.bBitsPerPixel = bBitsPixel;
+    DeleteObject( iinfo.hbmMask );
+    DeleteObject( iinfo.hbmColor );
 
-        hIcon=HICON_32(CreateCursorIconIndirect16(0, &info, lpANDbits, lpXORbits));
-    } else {
-        ICONINFO iinfo;
-        BITMAPINFO bmi;
-
-        iinfo.fIcon=TRUE;
-        iinfo.xHotspot=ICON_HOTSPOT;
-        iinfo.yHotspot=ICON_HOTSPOT;
-        iinfo.hbmMask=CreateBitmap(nWidth,nHeight,1,1,lpANDbits);
-
-        bmi.bmiHeader.biSize=sizeof(bmi.bmiHeader);
-        bmi.bmiHeader.biWidth=nWidth;
-        bmi.bmiHeader.biHeight=-nHeight;
-        bmi.bmiHeader.biPlanes=bPlanes;
-        bmi.bmiHeader.biBitCount=bBitsPixel;
-        bmi.bmiHeader.biCompression=BI_RGB;
-        bmi.bmiHeader.biSizeImage=0;
-        bmi.bmiHeader.biXPelsPerMeter=0;
-        bmi.bmiHeader.biYPelsPerMeter=0;
-        bmi.bmiHeader.biClrUsed=0;
-        bmi.bmiHeader.biClrImportant=0;
-
-        iinfo.hbmColor = CreateDIBitmap( hdc, &bmi.bmiHeader,
-                                         CBM_INIT, lpXORbits,
-                                         &bmi, DIB_RGB_COLORS );
-
-        hIcon=CreateIconIndirect(&iinfo);
-        DeleteObject(iinfo.hbmMask);
-        DeleteObject(iinfo.hbmColor);
-    }
-    ReleaseDC(0,hdc);
     return hIcon;
 }
 
@@ -1823,11 +1771,24 @@ HICON WINAPI CreateIconIndirect(PICONINFO iconinfo)
     HICON16 hObj;
     int	sizeXor,sizeAnd;
 
-    if (iconinfo->hbmColor) GetObjectA( iconinfo->hbmColor, sizeof(bmpXor), &bmpXor );
-    GetObjectA( iconinfo->hbmMask, sizeof(bmpAnd), &bmpAnd );
+    TRACE("color %p, mask %p, hotspot %ux%u, fIcon %d\n",
+           iconinfo->hbmColor, iconinfo->hbmMask,
+           iconinfo->xHotspot, iconinfo->yHotspot, iconinfo->fIcon);
+
+    if (iconinfo->hbmColor)
+    {
+        GetObjectW( iconinfo->hbmColor, sizeof(bmpXor), &bmpXor );
+        TRACE("color: width %d, height %d, width bytes %d, planes %u, bpp %u\n",
+               bmpXor.bmWidth, bmpXor.bmHeight, bmpXor.bmWidthBytes,
+               bmpXor.bmPlanes, bmpXor.bmBitsPixel);
+    }
+    GetObjectW( iconinfo->hbmMask, sizeof(bmpAnd), &bmpAnd );
+    TRACE("mask: width %d, height %d, width bytes %d, planes %u, bpp %u\n",
+           bmpAnd.bmWidth, bmpAnd.bmHeight, bmpAnd.bmWidthBytes,
+           bmpAnd.bmPlanes, bmpAnd.bmBitsPixel);
 
     sizeXor = iconinfo->hbmColor ? (bmpXor.bmHeight * bmpXor.bmWidthBytes) : 0;
-    sizeAnd = bmpAnd.bmHeight * bmpAnd.bmWidthBytes;
+    sizeAnd = bmpAnd.bmHeight * get_bitmap_width_bytes(bmpAnd.bmWidth, 1);
 
     hObj = GlobalAlloc16( GMEM_MOVEABLE,
                           sizeof(CURSORICONINFO) + sizeXor + sizeAnd );
@@ -1860,15 +1821,43 @@ HICON WINAPI CreateIconIndirect(PICONINFO iconinfo)
         else
         {
             info->nWidth        = bmpAnd.bmWidth;
-            info->nHeight       = bmpAnd.bmHeight / 2;
-            info->nWidthBytes   = bmpAnd.bmWidthBytes;
-            info->bPlanes       = bmpAnd.bmPlanes;
-            info->bBitsPerPixel = bmpAnd.bmBitsPixel;
+            info->nHeight       = bmpAnd.bmHeight * 2;
+            info->nWidthBytes   = get_bitmap_width_bytes(bmpAnd.bmWidth, 1);
+            info->bPlanes       = 1;
+            info->bBitsPerPixel = 1;
         }
 
         /* Transfer the bitmap bits to the CURSORICONINFO structure */
 
-        GetBitmapBits( iconinfo->hbmMask, sizeAnd, (char*)(info + 1) );
+        /* Some apps pass a color bitmap as a mask, convert it to b/w */
+        if (bmpAnd.bmBitsPixel == 1)
+        {
+            GetBitmapBits( iconinfo->hbmMask, sizeAnd, (char*)(info + 1) );
+        }
+        else
+        {
+            HDC hdc, hdc_mem;
+            HBITMAP hbmp_old, hbmp_mem_old, hbmp_mono;
+
+            hdc = GetDC( 0 );
+            hdc_mem = CreateCompatibleDC( hdc );
+
+            hbmp_mono = CreateBitmap( bmpAnd.bmWidth, bmpAnd.bmHeight, 1, 1, NULL );
+
+            hbmp_old = SelectObject( hdc, iconinfo->hbmMask );
+            hbmp_mem_old = SelectObject( hdc_mem, hbmp_mono );
+
+            BitBlt( hdc_mem, 0, 0, bmpAnd.bmWidth, bmpAnd.bmHeight, hdc, 0, 0, SRCCOPY );
+
+            SelectObject( hdc, hbmp_old );
+            SelectObject( hdc_mem, hbmp_mem_old );
+
+            DeleteDC( hdc_mem );
+            ReleaseDC( 0, hdc );
+
+            GetBitmapBits( hbmp_mono, sizeAnd, (char*)(info + 1) );
+            DeleteObject( hbmp_mono );
+        }
         if (iconinfo->hbmColor) GetBitmapBits( iconinfo->hbmColor, sizeXor, (char*)(info + 1) + sizeAnd );
         GlobalUnlock16( hObj );
     }
