@@ -46,9 +46,11 @@ static struct namespace *winstation_namespace;
 static void winstation_dump( struct object *obj, int verbose );
 static int winstation_close_handle( struct object *obj, struct process *process, obj_handle_t handle );
 static void winstation_destroy( struct object *obj );
+static unsigned int winstation_map_access( struct object *obj, unsigned int access );
 static void desktop_dump( struct object *obj, int verbose );
 static int desktop_close_handle( struct object *obj, struct process *process, obj_handle_t handle );
 static void desktop_destroy( struct object *obj );
+static unsigned int desktop_map_access( struct object *obj, unsigned int access );
 
 static const struct object_ops winstation_ops =
 {
@@ -60,7 +62,7 @@ static const struct object_ops winstation_ops =
     NULL,                         /* satisfied */
     no_signal,                    /* signal */
     no_get_fd,                    /* get_fd */
-    no_map_access,                /* map_access */
+    winstation_map_access,        /* map_access */
     no_lookup_name,               /* lookup_name */
     winstation_close_handle,      /* close_handle */
     winstation_destroy            /* destroy */
@@ -77,7 +79,7 @@ static const struct object_ops desktop_ops =
     NULL,                         /* satisfied */
     no_signal,                    /* signal */
     no_get_fd,                    /* get_fd */
-    no_map_access,                /* map_access */
+    desktop_map_access,           /* map_access */
     no_lookup_name,               /* lookup_name */
     desktop_close_handle,         /* close_handle */
     desktop_destroy               /* destroy */
@@ -139,6 +141,17 @@ static void winstation_destroy( struct object *obj )
     if (winstation->atom_table) release_object( winstation->atom_table );
 }
 
+static unsigned int winstation_map_access( struct object *obj, unsigned int access )
+{
+    if (access & GENERIC_READ)    access |= STANDARD_RIGHTS_READ | WINSTA_ENUMDESKTOPS | WINSTA_READATTRIBUTES |
+                                            WINSTA_ENUMERATE | WINSTA_READSCREEN;
+    if (access & GENERIC_WRITE)   access |= STANDARD_RIGHTS_WRITE | WINSTA_ACCESSCLIPBOARD | WINSTA_CREATEDESKTOP |
+                                            WINSTA_WRITEATTRIBUTES;
+    if (access & GENERIC_EXECUTE) access |= STANDARD_RIGHTS_EXECUTE | WINSTA_ACCESSGLOBALATOMS | WINSTA_EXITWINDOWS;
+    if (access & GENERIC_ALL)     access |= STANDARD_RIGHTS_REQUIRED | WINSTA_ALL_ACCESS;
+    return access & ~(GENERIC_READ | GENERIC_WRITE | GENERIC_EXECUTE | GENERIC_ALL);
+}
+
 /* retrieve the process window station, checking the handle access rights */
 struct winstation *get_process_winstation( struct process *process, unsigned int access )
 {
@@ -239,6 +252,17 @@ static void desktop_destroy( struct object *obj )
     release_object( desktop->winstation );
 }
 
+static unsigned int desktop_map_access( struct object *obj, unsigned int access )
+{
+    if (access & GENERIC_READ)    access |= STANDARD_RIGHTS_READ | DESKTOP_READOBJECTS | DESKTOP_ENUMERATE;
+    if (access & GENERIC_WRITE)   access |= STANDARD_RIGHTS_WRITE | DESKTOP_CREATEMENU | DESKTOP_CREATEWINDOW |
+                                            DESKTOP_HOOKCONTROL | DESKTOP_JOURNALRECORD | DESKTOP_JOURNALPLAYBACK |
+                                            DESKTOP_WRITEOBJECTS;
+    if (access & GENERIC_EXECUTE) access |= STANDARD_RIGHTS_EXECUTE | DESKTOP_SWITCHDESKTOP;
+    if (access & GENERIC_ALL)     access |= STANDARD_RIGHTS_REQUIRED | DESKTOP_ALL_ACCESS;
+    return access & ~(GENERIC_READ | GENERIC_WRITE | GENERIC_EXECUTE | GENERIC_ALL);
+}
+
 /* retrieve the thread desktop, checking the handle access rights */
 struct desktop *get_thread_desktop( struct thread *thread, unsigned int access )
 {
@@ -337,8 +361,7 @@ void close_process_desktop( struct process *process )
         /* if we have one remaining user, it has to be the manager of the desktop window */
         if (desktop->users == 1 && get_top_window_owner( desktop ))
         {
-            struct timeval when;
-            gettimeofday( &when, NULL );
+            struct timeval when = current_time;
             add_timeout( &when, 1000 );
             assert( !desktop->close_timeout );
             desktop->close_timeout = add_timeout_user( &when, close_desktop_timeout, desktop );
@@ -354,7 +377,7 @@ void close_thread_desktop( struct thread *thread )
     obj_handle_t handle = thread->desktop;
 
     thread->desktop = 0;
-    if (handle) close_handle( thread->process, handle, NULL );
+    if (handle) close_handle( thread->process, handle );
     clear_error();  /* ignore errors */
 }
 
@@ -396,7 +419,7 @@ DECL_HANDLER(close_winstation)
     if ((winstation = (struct winstation *)get_handle_obj( current->process, req->handle,
                                                            0, &winstation_ops )))
     {
-        if (!close_handle( current->process, req->handle, NULL )) set_error( STATUS_ACCESS_DENIED );
+        if (!close_handle( current->process, req->handle )) set_error( STATUS_ACCESS_DENIED );
         release_object( winstation );
     }
 }
@@ -475,7 +498,7 @@ DECL_HANDLER(close_desktop)
     if ((desktop = (struct desktop *)get_handle_obj( current->process, req->handle,
                                                      0, &desktop_ops )))
     {
-        if (!close_handle( current->process, req->handle, NULL )) set_error( STATUS_DEVICE_BUSY );
+        if (!close_handle( current->process, req->handle )) set_error( STATUS_DEVICE_BUSY );
         release_object( desktop );
     }
 }
